### FileSeeker
email: [antineutrinomuon@gmail.com](mailto:antineutrinomuon@gmail.com), [jean@astro.up.pt](mailto:jean@astro.up.pt)

last stable version: 0.0.2

Under &beta; distribution phase - The README file is not complete. Conda is not exported yet. Tutorials will be made asap.

github repository: <a href='https://github.com/neutrinomuon/FileSeeker/'>FileSeeker</a>

© Copyright ®

J.G. - Jean Gomes

<hr>

<img src='https://img.shields.io/pypi/pyversions/FileSeeker'>

<hr>

#### <b>RESUME</b>

<img src="https://raw.githubusercontent.com/neutrinomuon/FileSeeker/main/figures/FileSeeker.png" width=120>

Search in your directory and subdirectories recursively to find a file with a
given pattern.

<hr>

#### <b>INSTALLATION</b>

You can easily install <a href='https://pypi.org/project/FileSeeker/'>FileSeeker</a> by using pip - <a href='https://pypi.org/'>PyPI - The Python Package Index</a>:

<pre>
pip install FileSeeker
</pre>

<br>or by using a generated conda repository <a href='https://anaconda.org/neutrinomuon/FileSeeker'>https://anaconda.org/neutrinomuon/FileSeeker</a>:

<img src='https://anaconda.org/neutrinomuon/FileSeeker/badges/version.svg'><img src='https://anaconda.org/neutrinomuon/FileSeeker/badges/latest_release_date.svg'><img src='https://anaconda.org/neutrinomuon/FileSeeker/badges/platforms.svg'>

<pre>
conda install -c neutrinomuon FileSeeker
</pre>

<br>OBS.: Linux, OS-X ad Windows pre-compilations available in conda.

You can also clone the repository and install by yourself in your machine:

<pre>
git clone https://github.com/neutrinomuon/FileSeeker
python setup.py install
</pre>

<hr>

#### <b>EXAMPLE</b>

Example of the FileSeeker script in python

<img src="https://github.com/neutrinomuon/FileSeeker/blob/main/figures/FileSeeker_Screenshot.png?raw=true" width="90%">

<hr>

#### <b>STRUCTURE OF FileSeeker (Created with FileSeeker)</b>

<pre>
#################################################
FileSeeker
├── README.md
├── figures
│   └── cc_logo.png
├── src
│   └── python
└── .git
    ├── branches
    ├── logs
    ├── info
    ├── index
    ├── description
    ├── HEAD
    ├── objects
    ├── packed-refs
    ├── hooks
    ├── COMMIT_EDITMSG
    ├── refs
    └── config

10 directories, 8 files
#################################################
Generated with tree_colored @ 2023 - © Jean Gomes
#################################################
</pre>

<hr>

#### <b>ISSUES AND CONTRIBUTIONS</b>

If you encounter any issues with this project, please feel free to submit an
issue on the GitHub repository. We appreciate your feedback and are committed
to improving the quality of our codebase.

If you'd like to contribute to this project, we welcome pull requests from the
community. Before submitting a pull request, please make sure to fork the
repository and create a new branch for your changes. Once your changes are
complete, submit a pull request and we'll review your code as soon as
possible.

For any questions or concerns about contributing, please contact the project
maintainer at antineutrinomuon@gmail.com. Thank you for your interest in
contributing to our project!

<hr>

#### <b>LICENSE</b>

Attribution-NonCommercial-NoDerivatives 4.0 (CC BY-NC-ND 4.0)

<img src="https://github.com/neutrinomuon/FileSeeker/blob/main/figures/cc_logo.png?raw=true" width="10%">

<a href='https://creativecommons.org/licenses/by-nc-nd/4.0/'>Creative Commons Attribution-NonCommercial-NoDerivs (CC-BY-NC-ND)</a>

